pub struct Connection { /* private fields */ }Expand description
Represents an individual client connection.
Implementations
Sourceimpl Connection
impl Connection
Sourcepub fn new(
id: u64,
stream: TcpStream,
handler: Arc<dyn Handler>,
config: ConnectionConfig,
) -> Self
pub fn new( id: u64, stream: TcpStream, handler: Arc<dyn Handler>, config: ConnectionConfig, ) -> Self
Create a new connection wrapper with a monotonically increasing id.
Sourcepub async fn run(self) -> Result<(), ConnectionError>
pub async fn run(self) -> Result<(), ConnectionError>
Drive the connection until it terminates, handling pipelined requests in order.