init

Function init 

pub fn init()
Initialise a default tracing subscriber if none has been installed.

Subsequent calls are no-ops, allowing libraries, binaries, and tests to call this function without worrying about double initialisation panics.