Request

Struct Request 

pub struct Request { /* private fields */ }
Represents an HTTP request.

Implementations

Source

impl Request

pub fn new(method: Method, target: RequestTarget) -> Self

Create a new request using HTTP/1.1 as the default version.

pub fn builder(method: Method, target: RequestTarget) -> RequestBuilder

Construct a request builder for incremental configuration.

pub fn method(&self) -> &Method

Return the request method.

pub fn target(&self) -> &RequestTarget

Return the request target.

pub fn version(&self) -> HttpVersion

Return the HTTP version.

pub fn headers(&self) -> &Headers

Borrow the header map.

pub fn header(&self, name: impl Into<HeaderName>) -> Option<&str>

Retrieve the first value for the specified header name.

pub fn contains_header(&self, name: impl Into<HeaderName>) -> bool

Returns true if a header with the specified name is present.

pub fn body(&self) -> &Body

Borrow the body representation.

pub fn body_bytes(&self) -> &Bytes

Borrow the buffered body bytes.

pub fn headers_mut(&mut self) -> &mut Headers

Borrow the header map mutably.

pub fn set_version(&mut self, version: HttpVersion)

Set the HTTP version for the request.

pub fn set_body(&mut self, body: Body)

Set the body representation.

pub fn set_body_bytes(&mut self, bytes: impl Into<Bytes>)

Replace the buffered body bytes.

pub fn into_body_bytes(self) -> Bytes

Consume the request and return the buffered body bytes.

pub fn take_body_bytes(&mut self) -> Bytes

Remove and return the buffered body bytes, leaving an empty buffer.

pub fn expect_100_continue(&self) -> bool

Whether the request includes Expect: 100-continue in its header section.

pub fn wants_close(&self) -> bool

Determine whether the request prefers the connection to close.

pub fn if_none_match(&self) -> Option<&str>

Retrieve the If-None-Match header value trimmed of whitespace.

pub fn if_match(&self) -> Option<&str>

Retrieve the If-Match header value trimmed of whitespace.

pub fn if_unmodified_since(&self) -> Option<SystemTime>

Retrieve the If-Unmodified-Since value as SystemTime.

pub fn if_modified_since(&self) -> Option<SystemTime>

Retrieve the If-Modified-Since value as SystemTime.